bayespy.nodes.CategoricalMarkovChain.broadcasting_multiplier
============================================================

.. currentmodule:: bayespy.nodes

.. automethod:: CategoricalMarkovChain.broadcasting_multiplier